@@ -2,13 +2,13 @@ package App::PerlXLock;
 use strict;
 use warnings;
 use base 'Exporter';
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 our @EXPORT  = qw(main_loop);
 use Inline C => Config => LIBS => '-lX11';
 use Inline
   C       => "DATA",
   NAME    => "App::PerlXLock",
-  VERSION => '0.02',
+  VERSION => '0.03',
   INC     => '/usr/include';
 
 END {
@@ -36,14 +36,7 @@ sub shadow_readable {
 }
 
 sub password_accessible {
-    has_shadow() && shadow_readable();
-}
-
-sub open_locks {
-    my $d = shift();
-    for (@windows) {
-        close_window( $d, $_ );
-    }
+    $ENV{PLOCK_PASSWORD} || ( has_shadow() && shadow_readable() );
 }
 
 sub check_event {
@@ -51,6 +44,12 @@ sub check_event {
     $ev > 0 ? push( @buffer, chr($ev) ) : undef;
 }
 
+sub check_password {
+    my $pw = shift;
+    defined( $ENV{PLOCK_PASSWORD} ) && return($ENV{PLOCK_PASSWORD} eq $pw);
+    check_unix_password($pw) == 0;
+}
+
 sub main_loop {
     my $d = open_connection();
     lock_all($d);
@@ -62,7 +61,7 @@ sub main_loop {
             pop(@buffer);
             if ( password_accessible() ) {
                 for my $n ( 0 .. $#buffer ) {
-                    if ( check_password( join( "", @buffer[ $n .. $#buffer ] ) ) == 0 ) {
+                    if ( check_password( join( "", @buffer[ $n .. $#buffer ] ) ) ) {
                         $locked = 0;
                     }
                 }
@@ -75,6 +74,7 @@ sub main_loop {
     }
     unlock_all($d);
     ungrab_keyboard($d);
+    close_connection($d);
 }
 
 sub unlock_all {
@@ -82,9 +82,12 @@ sub unlock_all {
     destroy_window( $d, $_ ) for (@windows);
 }
 
-has_shadow() || print "/etc/shadow does not exist. Xlock is not password protected.\n";
-shadow_readable
-  || print "No permissions to read /etc/shadow. Xlock is not password protected.\n";
+unless ( $ENV{PLOCK_PASSWORD} ) {
+    has_shadow()
+      || print "/etc/shadow does not exist. Xlock is not password protected.\n";
+    shadow_readable
+      || print "No permissions to read /etc/shadow. Xlock is not password protected.\n";
+}
 
 1;
 
@@ -192,7 +195,7 @@ int read_event(SV *d){
 }
 
 
-int check_password(char *checkpw){
+int check_unix_password(char *checkpw){
     struct spwd *entry;
     char *pw;
     entry = getspnam(getenv("USER"));
@@ -209,14 +212,17 @@ App::PerlXLock - A simple X locking utility.
     #lock without password
     plock 
 
-    #When using perlbrew, run lock with password read from /etc/shadow.
-    #Add NOPASSWD to sudoers accordingly.
+    #When using perlbrew, the following zsh command runs lock with password read from /etc/shadow.
+    #Add NOPASSWD to sudoers accordingly. 
     sudo $(which perl) $(which plock)
 
+    #lock with password given in an environmental variable
+    PLOCK_PASSWORD="password" plock
+
 =head1 DESCRIPTION
 
 A X11 locking utility. plock turns the screen black and waits for a key press. If /etc/shadow
-is not accessible, plock terminates after pressing return. If /etc/shadow
+is not accessible and PLOCK_PASSWORD is not set, plock terminates after pressing return. If /etc/shadow
 is found to be readable, then it waits until the user has typed his password and pressed return. 
 
 In case of mistyping the password, simply retype as plock detects once the correct password
@@ -224,7 +230,7 @@ appears in the buffer.
 
 =head1 CAVEATS
 
-At the moment, works only with systems having a shadow password file.
+At the moment, recognizes only a shadow password file or the environmental variable.
 
 =head1 LICENSE
 
